/*******************************************************************************
* File Name: reset_spi_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "reset_spi.h"

/* Check for removal by optimization */
#if !defined(reset_spi_Sync_ctrl_reg__REMOVED)

static reset_spi_BACKUP_STRUCT  reset_spi_backup = {0u};

    
/*******************************************************************************
* Function Name: reset_spi_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void reset_spi_SaveConfig(void) 
{
    reset_spi_backup.controlState = reset_spi_Control;
}


/*******************************************************************************
* Function Name: reset_spi_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void reset_spi_RestoreConfig(void) 
{
     reset_spi_Control = reset_spi_backup.controlState;
}


/*******************************************************************************
* Function Name: reset_spi_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void reset_spi_Sleep(void) 
{
    reset_spi_SaveConfig();
}


/*******************************************************************************
* Function Name: reset_spi_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void reset_spi_Wakeup(void)  
{
    reset_spi_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
