/*******************************************************************************
* File Name: spi_rst_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "spi_rst.h"

/* Check for removal by optimization */
#if !defined(spi_rst_Sync_ctrl_reg__REMOVED)

static spi_rst_BACKUP_STRUCT  spi_rst_backup = {0u};

    
/*******************************************************************************
* Function Name: spi_rst_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void spi_rst_SaveConfig(void) 
{
    spi_rst_backup.controlState = spi_rst_Control;
}


/*******************************************************************************
* Function Name: spi_rst_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void spi_rst_RestoreConfig(void) 
{
     spi_rst_Control = spi_rst_backup.controlState;
}


/*******************************************************************************
* Function Name: spi_rst_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void spi_rst_Sleep(void) 
{
    spi_rst_SaveConfig();
}


/*******************************************************************************
* Function Name: spi_rst_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void spi_rst_Wakeup(void)  
{
    spi_rst_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
